import { StandardEnum } from "./enum";
/**
 * Methods to help caching data of any type.
 * Data is put in containers and may be identified by a string key.
 * Data can be saved, retrieved and reset.
 * Based on Neolution.Abstractions.Caching.CacheProvider<TEnum>
 * Ref: https://github.com/neolution-ch/Neolution.Abstractions/blob/main/Neolution.Abstractions/Caching/CacheProvider.cs
 */
export declare class CacheProvider<TEnum> {
    /**
     * The enum variable
     */
    private readonly enumVariable;
    /**
     * The name of the cache
     */
    private readonly cacheName;
    /**
     * The cache
     */
    private readonly cache;
    /**
     * Initializes a new instance of the CacheProvider<TEnum> class
     * @param enumVariable The enum variable
     * @param cacheName The name of the cache
     */
    constructor(enumVariable: StandardEnum<TEnum>, cacheName: string);
    /**
     * Creates the cache key
     * @param container The container
     * @param key The key
     * @returns The cache key
     */
    private createCacheKey;
    /**
     * Gets cached data from the specified container
     * @param container The container
     * @param key The key
     * @returns The data from cache
     */
    getObject<T>(container: TEnum, key?: string): T | undefined;
    /**
     * Sets cached data identified by a key in the specified container
     * @param container The container
     * @param key The key
     * @param cacheObject The cache object
     */
    setObject<T>(container: TEnum, key: string | undefined, cacheObject: T): void;
    /**
     * Resets cached data identified by a key of the specified container
     * @param container The container
     * @param key The key
     */
    reset(container: TEnum, key?: string): void;
}
